@@ -2,6 +2,19 @@ import fire
 import os
 from pywinschedule.watcher import Watcher
 from pywinschedule.utils.admin import isUserAdmin,runAsAdmin
+from pywinschedule.config import HOME
+def generate_hash(s, times=1):
+    assert times >= 1
+    import hashlib
+    m = hashlib.md5()
+
+    def gen():
+        m.update(s.encode('utf-8'))
+        return m.hexdigest()[:10]
+
+    for i in range(times):
+        data = gen()
+    return data
 if not isUserAdmin():
     runAsAdmin()
 
@@ -20,10 +33,22 @@ class CLI:
                 0  # want current value, shellcon.SHGFP_TYPE_CURRENT isn't available, this seems to work
             )
         STARTUP_PATH=startupdirectory()
-        bat_path=os.path.join(STARTUP_PATH,'pywinschedule_watch.bat')
-        print('Writing to %s'%(bat_path))
+        name='pywinschedule_watch_%s'%(generate_hash(os.path.abspath(path)))
+        bat_path=os.path.join(
+            HOME,
+            name+'.bat'
+        )
+        bat_content='pywinschedule watch %s'%(os.path.abspath(path))
+        vbs_path=os.path.join(
+            STARTUP_PATH,
+            name+'.vbs'
+        )
+        vbs_content='CreateObject("Wscript.Shell").Run "%s", 0, True'%(bat_path)
+        print('Writing to %s , %s'%(bat_path,vbs_path))
         with open(bat_path,'w') as f:
-            f.write('pywinschedule watch %s'%(path))
+            f.write(bat_content)
+        with open(vbs_path,'w') as f:
+            f.write(vbs_content)
         cls.watch(path)
     @classmethod
     def watch(cls,path):
